# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgname openvswitch3.4


%if 0%{?commit:1}
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%endif

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

%global rpm_supports_sysysers_m    %(rpm --version | awk -e '{print ($3 > 4.20)}')

# FIXME Test "STP - flush the fdb and mdb when topology changed" fails on s390x
# FIXME 2 tests fails on ppc64le. They will be hopefully fixed before official 2.11
%ifarch %{ix86} x86_64 aarch64
%bcond_without check
%else
%bcond_with check
%endif
# option to run kernel datapath tests, requires building as root!
%bcond_with check_datapath_kernel
# option to build with libcap-ng, needed for running OVS as regular user
%bcond_without libcapng
# option to build with ipsec support
%bcond_without ipsec

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

Name: %{pkgname}
Summary: Open vSwitch
Group: System Environment/Daemons daemon/database/utilities
URL: http://www.openvswitch.org/
Version: 3.4.2
Release: 62%{?dist}

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
# datapath/ is GPLv2 (although not built into any of the binary packages)
License: ASL 2.0 and LGPLv2+ and SISSL

%define dpdkver 23.11
%define dpdkdir dpdk
%define dpdksver %(echo %{dpdkver} | cut -d. -f-2)
# NOTE: DPDK does not currently build for s390x
# DPDK on aarch64 is not stable enough to be enabled in FDP
%if 0%{?rhel} > 7 || 0%{?fedora}
%define dpdkarches x86_64 ppc64le
%else
%define dpdkarches
%endif

%define ovsver 3.4.0
%if 0%{?commit:1}
Source: https://github.com/openvswitch/ovs/archive/%{commit}.tar.gz#/openvswitch-%{commit}.tar.gz
%else
Source: https://github.com/openvswitch/ovs/archive/v%{ovsver}.tar.gz#/openvswitch-%{ovsver}.tar.gz
%endif
Source2: openvswitch.sysusers
Source3: openvswitch-hugetlbfs.sysusers
Source10: https://fast.dpdk.org/rel/dpdk-%{dpdkver}.tar.xz

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.2.3
%define pyelftoolsver 0.27
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz
Source103: https://pypi.io/packages/source/p/pyelftools/pyelftools-%{pyelftoolsver}.tar.gz

Patch0:    openvswitch-%{ovsver}.patch

# The DPDK is designed to optimize througput of network traffic using, among
# other techniques, carefully crafted assembly instructions.  As such it
# needs extensive work to port it to other architectures.
ExclusiveArch: x86_64 aarch64 ppc64le s390x

# Do not enable this otherwise YUM will break on any upgrade.
# Provides: openvswitch
Conflicts: openvswitch < 3.4
Conflicts: openvswitch-dpdk < 3.4
Conflicts: openvswitch2.10
Conflicts: openvswitch2.11
Conflicts: openvswitch2.12
Conflicts: openvswitch2.13
Conflicts: openvswitch2.14
Conflicts: openvswitch2.15
Conflicts: openvswitch2.16
Conflicts: openvswitch2.17
Conflicts: openvswitch3.0
Conflicts: openvswitch3.1
Conflicts: openvswitch3.2
Conflicts: openvswitch3.3

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units systemd-rpm-macros openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel
BuildRequires: systemtap-sdt-devel
# make check dependencies
BuildRequires: procps-ng
%if %{with check_datapath_kernel}
BuildRequires: nmap-ncat
# would be useful but not available in RHEL or EPEL
#BuildRequires: pyftpdlib
%endif

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

%ifarch %{dpdkarches}
BuildRequires: meson
%if 0%{?rhel} > 8 || 0%{?fedora}
BuildRequires: python3-pyelftools
%endif
# DPDK driver dependencies
BuildRequires: zlib-devel numactl-devel libarchive-devel
# libarchive static dependencies
BuildRequires: bzip2-devel libacl-devel libxml2-devel libzstd-devel lz4-devel xz-devel
%ifarch x86_64
BuildRequires: rdma-core-devel >= 15 libmnl-devel
%endif

# Required by packaging policy for the bundled DPDK
Provides: bundled(dpdk) = %{dpdkver}
%endif

Requires: openssl iproute module-init-tools
#Upstream kernel commit 4f647e0a3c37b8d5086214128614a136064110c3
#Requires: kernel >= 3.15.0-0
Requires: openvswitch-selinux-extra-policy

%{?sysusers_requires_compat}
%if ! %rpm_supports_sysysers_m
Requires(post): /usr/sbin/usermod
%endif
Requires(post): /bin/sed
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
Obsoletes: openvswitch-controller <= 0:2.1.0-1

%if 0%{?rhel}
# sortedcontainers are not packaged on RHEL yet, but ovs includes it
%global __requires_exclude ^python%{python3_version}dist\\(sortedcontainers\\)$
%endif

%description
Open vSwitch provides standard network bridging functions and
support for the OpenFlow protocol for remote per-flow control of
traffic.

%package -n python3-%{pkgname}
Summary: Open vSwitch python3 bindings
License: ASL 2.0
Requires: %{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Provides: python-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}

%description -n python3-%{pkgname}
Python bindings for the Open vSwitch database

%package test
Summary: Open vSwitch testing utilities
License: ASL 2.0
BuildArch: noarch
Requires: python3-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: tcpdump

%description test
Utilities that are useful to diagnose performance and connectivity
issues in Open vSwitch setup.

%package devel
Summary: Open vSwitch OpenFlow development package (library, headers)
License: ASL 2.0
Requires: %{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}

%description devel
This provides shared library, libopenswitch.so and the openvswitch header
files needed to build an external application.

%if 0%{?rhel} == 8 || 0%{?fedora} > 28
%package -n network-scripts-%{name}
Summary: Open vSwitch legacy network service support
License: ASL 2.0
Requires: network-scripts
Supplements: (%{name} and network-scripts)

%description -n network-scripts-%{name}
This provides the ifup and ifdown scripts for use with the legacy network
service.
%endif

%if %{with ipsec}
%package ipsec
Summary: Open vSwitch IPsec tunneling support
License: ASL 2.0
Requires: python3-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: libreswan

%description ipsec
This package provides IPsec tunneling support for OVS tunnels.
%endif

%prep
%if 0%{?commit:1}
%setup -q -n ovs-%{commit} -a 10
%else
%setup -q -n ovs-%{ovsver} -a 10
%endif
%if ! %{external_sphinx}
%if 0%{?commit:1}
%setup -n ovs-%{commit} -q -D -T -a 100 -a 101 -a 102
%else
%setup -n ovs-%{ovsver} -q -D -T -a 100 -a 101 -a 102
%endif
%endif
%if 0%{?rhel} && 0%{?rhel} < 9
%if 0%{?commit:1}
%setup -n ovs-%{commit} -q -D -T -a 103
%else
%setup -n ovs-%{ovsver} -q -D -T -a 103
%endif
%endif

mv dpdk-*/ %{dpdkdir}/

%if 0%{?PATCH0:1}%{!?PATCH0:0}
%patch -P0 -p1
%endif

%build
%if 0%{?rhel} && 0%{?rhel} < 9
export PYTHONPATH="${PWD}/pyelftools-%{pyelftoolsver}"
%endif
# Build Sphinx on RHEL
%if ! %{external_sphinx}
export PYTHONPATH="${PYTHONPATH:+$PYTHONPATH:}%{_builddir}/pytmp/lib/python"
for x in docutils-%{docutilsver} Pygments-%{pygmentsver} Sphinx-%{sphinxver}; do
    pushd "$x"
    python2 setup.py install --home %{_builddir}/pytmp
    popd
done

export PATH="$PATH:%{_builddir}/pytmp/bin"
%endif

./boot.sh

%ifarch %{dpdkarches}
# Lets build DPDK first
cd %{dpdkdir}

ENABLED_DRIVERS=(
    bus/pci
    bus/vdev
    mempool/ring
    net/failsafe
    net/i40e
    net/ring
    net/vhost
    net/virtio
    net/tap
)

%ifarch x86_64
ENABLED_DRIVERS+=(
    bus/auxiliary
    bus/vmbus
    common/iavf
    common/mlx5
    net/bnxt
    net/enic
    net/iavf
    net/ice
    net/mlx5
    net/netvsc
    net/nfp
    net/qede
    net/vdev_netvsc
%if "%{dpdkver}" >= "23.11"
    baseband/acc
    common/nfp
%endif
)
%endif

%ifarch aarch64 x86_64
ENABLED_DRIVERS+=(
    net/e1000
    net/ixgbe
)
%endif

for driver in "${ENABLED_DRIVERS[@]}"; do
    enable_drivers="${enable_drivers:+$enable_drivers,}"$driver
done

# If doing any updates, this must be aligned with:
# https://access.redhat.com/articles/3538141
%if "%{dpdkver}" < "23.11"
DISABLED_LIBS=(
    gpudev
    kni
    jobstats
    power
)

for lib in "${DISABLED_LIBS[@]}"; do
    disable_libs="${disable_libs:+$disable_libs,}"$lib
done
%else
ENABLED_LIBS=(
    bbdev
    bitratestats
    bpf
    cmdline
    cryptodev
    dmadev
    gro
    gso
    hash
    ip_frag
    latencystats
    member
    meter
    metrics
    pcapng
    pdump
    security
    stack
    vhost
)

for lib in "${ENABLED_LIBS[@]}"; do
    enable_libs="${enable_libs:+$enable_libs,}"$lib
done
%endif

%set_build_flags
%__meson --prefix=%{_builddir}/dpdk-build \
         --buildtype=plain \
%if "%{dpdkver}" < "23.11"
         -Ddisable_libs="$disable_libs" \
%else
         -Denable_libs="$enable_libs" \
%endif
         -Ddisable_apps="*" \
         -Denable_drivers="$enable_drivers" \
         -Dplatform=generic \
         -Dmax_ethports=1024 \
         -Dmax_numa_nodes=8 \
         -Dtests=false \
         %{_vpath_builddir}
%meson_build
%__meson install -C %{_vpath_builddir} --no-rebuild

# FIXME currently with LTO enabled OVS tries to link with both static and shared libraries
rm -v %{_builddir}/dpdk-build/%{_lib}/*.so*

# Generate a list of supported drivers, its hard to tell otherwise.
cat << EOF > README.DPDK-PMDS
DPDK drivers included in this package:

EOF

for f in %{_builddir}/dpdk-build/%{_lib}/librte_net_*.a; do
    basename ${f} | cut -c12- | cut -d. -f1 | tr [:lower:] [:upper:]
done >> README.DPDK-PMDS

cat << EOF >> README.DPDK-PMDS

For further information about the drivers, see
http://dpdk.org/doc/guides-%{dpdksver}/nics/index.html
EOF

cd -
%endif

# And now for OVS...
mkdir build-shared build-static
pushd build-shared
ln -s ../configure
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --disable-static \
        --enable-shared \
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki \
        --enable-usdt-probes \
        --disable-afxdp \
        --with-version-suffix=-%{release}
make %{?_smp_mflags}
popd
pushd build-static
ln -s ../configure
%ifarch %{dpdkarches}
PKG_CONFIG_PATH=%{_builddir}/dpdk-build/%{_lib}/pkgconfig \
%endif
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
%ifarch %{dpdkarches}
        --with-dpdk=static \
%endif
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki \
        --enable-usdt-probes \
        --disable-afxdp \
        --with-version-suffix=-%{release}
make %{?_smp_mflags}
popd

/usr/bin/python3 build-aux/dpdkstrip.py \
        --dpdk \
        < rhel/usr_lib_systemd_system_ovs-vswitchd.service.in \
        > rhel/usr_lib_systemd_system_ovs-vswitchd.service

%install
rm -rf $RPM_BUILD_ROOT
make -C build-shared install sbin_PROGRAMS=ovsdb/ovsdb-server DESTDIR=$RPM_BUILD_ROOT
make -C build-static install bin_PROGRAMS= sbin_PROGRAMS=vswitchd/ovs-vswitchd DESTDIR=$RPM_BUILD_ROOT

install -d -m 0755 $RPM_BUILD_ROOT%{_rundir}/openvswitch
install -d -m 0750 $RPM_BUILD_ROOT%{_localstatedir}/log/openvswitch
install -d -m 0755 $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch

install -p -D -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysusersdir}/openvswitch.conf
%ifarch %{dpdkarches}
install -p -D -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{_sysusersdir}/openvswitch-hugetlbfs.conf
%endif

install -p -D -m 0644 rhel/usr_lib_udev_rules.d_91-vfio.rules \
        $RPM_BUILD_ROOT%{_udevrulesdir}/91-vfio.rules

install -p -D -m 0644 \
        rhel/usr_share_openvswitch_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/openvswitch

for service in openvswitch ovsdb-server ovs-vswitchd \
               ovs-delete-transient-ports; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

%if %{with ipsec}
install -p -D -m 0644 rhel/usr_lib_systemd_system_openvswitch-ipsec.service \
                      $RPM_BUILD_ROOT%{_unitdir}/openvswitch-ipsec.service
%endif

install -m 0755 rhel/etc_init.d_openvswitch \
        $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/openvswitch.init

install -p -D -m 0644 rhel/etc_openvswitch_default.conf \
        $RPM_BUILD_ROOT/%{_sysconfdir}/openvswitch/default.conf

install -p -D -m 0644 rhel/etc_logrotate.d_openvswitch \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/openvswitch

install -m 0644 vswitchd/vswitch.ovsschema \
        $RPM_BUILD_ROOT/%{_datadir}/openvswitch/vswitch.ovsschema

%if 0%{?rhel} < 9
install -d -m 0755 $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifdown-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifup-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%endif

install -d -m 0755 $RPM_BUILD_ROOT%{python3_sitelib}
cp -a $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/ovstest \
        $RPM_BUILD_ROOT%{python3_sitelib}

# Build the JSON C extension for the Python lib (#1417738)
pushd python
(
export CPPFLAGS="-I ../include -I ../build-shared/include"
export LDFLAGS="%{__global_ldflags} -L $RPM_BUILD_ROOT%{_libdir}"
%py3_build
%py3_install
[ -f "$RPM_BUILD_ROOT/%{python3_sitearch}/ovs/_json$(python3-config --extension-suffix)" ]
)
popd

rm -rf $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/openvswitch

install -d -m 0755 $RPM_BUILD_ROOT%{_prefix}/lib/firewalld/services/

install -p -D -m 0755 \
        rhel/usr_share_openvswitch_scripts_ovs-systemd-reload \
        $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/ovs-systemd-reload

touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/conf.db
# The db needs special permission as IPsec Pre-shared keys are stored in it.
chmod 0640 $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/conf.db

touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/system-id.conf

# remove unpackaged files
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovs-benchmark \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-docker \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-parse-backtrace \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-testcontroller \
        $RPM_BUILD_ROOT/%{_sbindir}/ovs-vlan-bug-workaround \
        $RPM_BUILD_ROOT/%{_mandir}/man1/ovs-benchmark.1* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-testcontroller.* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-vlan-bug-workaround.8*

%if ! %{with ipsec}
rm -f $RPM_BUILD_ROOT/%{_datadir}/openvswitch/scripts/ovs-monitor-ipsec
%endif

# remove ovn unpackages files
rm -f $RPM_BUILD_ROOT%{_bindir}/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovn*
rm -f $RPM_BUILD_ROOT%{_datadir}/openvswitch/ovn*
rm -f $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/ovn*
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*

%check
%if %{with check}
    pushd build-static
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if make check TESTSUITEFLAGS='%{_smp_mflags}' ||
       make check TESTSUITEFLAGS='--recheck'; then :;
    else
        cat tests/testsuite.log
        exit 1
    fi
    popd
%endif
%if %{with check_datapath_kernel}
    pushd build-static
    if make check-kernel RECHECK=yes; then :;
    else
        cat tests/system-kmod-testsuite.log
        exit 1
    fi
    popd
%endif

%preun
%if 0%{?systemd_preun:1}
    %systemd_preun openvswitch.service
%else
    if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
        /bin/systemctl --no-reload disable openvswitch.service >/dev/null 2>&1 || :
        /bin/systemctl stop openvswitch.service >/dev/null 2>&1 || :
    fi
%endif

%pre
%sysusers_create_compat %{SOURCE2}
%ifarch %{dpdkarches}
%sysusers_create_compat %{SOURCE3}
%if ! %rpm_supports_sysysers_m
usermod -a -G hugetlbfs openvswitch
%endif
%endif

%post
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVS_USER_ID=:OVS_USER_ID=:' /etc/sysconfig/openvswitch

%ifarch %{dpdkarches}
    sed -i \
        's@OVS_USER_ID="openvswitch:openvswitch"@OVS_USER_ID="openvswitch:hugetlbfs"@'\
        /etc/sysconfig/openvswitch
%endif
fi
chown -R openvswitch:openvswitch /etc/openvswitch

%if 0%{?systemd_post:1}
    %systemd_post openvswitch.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun
%if 0%{?systemd_postun:1}
    %systemd_postun openvswitch.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
%endif

%triggerun -- openvswitch < 2.5.0-22.git20160727%{?dist}
# old rpm versions restart the service in postun, but
# due to systemd some preparation is needed.
if systemctl is-active openvswitch >/dev/null 2>&1 ; then
    /usr/share/openvswitch/scripts/ovs-ctl stop >/dev/null 2>&1 || :
    systemctl daemon-reload >/dev/null 2>&1 || :
    systemctl stop openvswitch ovsdb-server ovs-vswitchd >/dev/null 2>&1 || :
    systemctl start openvswitch >/dev/null 2>&1 || :
fi
exit 0

%files -n python3-%{pkgname}
%{python3_sitearch}/ovs
%{python3_sitearch}/ovs-*.egg-info
%if "%{version}" >= "3.5.0"
%{_bindir}/ovs-flowviz
%{_mandir}/man8/ovs-flowviz.8*
%endif
%doc LICENSE

%files test
%{_bindir}/ovs-pcap
%{_bindir}/ovs-tcpdump
%{_bindir}/ovs-tcpundump
%{_datadir}/openvswitch/scripts/usdt/*
%{_mandir}/man1/ovs-pcap.1*
%{_mandir}/man8/ovs-tcpdump.8*
%{_mandir}/man1/ovs-tcpundump.1*
%{_bindir}/ovs-test
%{_bindir}/ovs-vlan-test
%{_bindir}/ovs-l3ping
%{_mandir}/man8/ovs-test.8*
%{_mandir}/man8/ovs-vlan-test.8*
%{_mandir}/man8/ovs-l3ping.8*
%{python3_sitelib}/ovstest

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/openvswitch/*
%{_includedir}/openflow/*
%exclude %{_libdir}/*.a
%exclude %{_libdir}/*.la

%if 0%{?rhel} == 8 || 0%{?fedora} > 28
%files -n network-scripts-%{name}
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%endif

%files
%defattr(-,openvswitch,openvswitch)
%dir %{_sysconfdir}/openvswitch
%{_sysconfdir}/openvswitch/default.conf
%config %ghost %verify(not owner group md5 size mtime) %{_sysconfdir}/openvswitch/conf.db
%ghost %attr(0600,-,-) %verify(not owner group md5 size mtime) %{_sysconfdir}/openvswitch/.conf.db.~lock~
%config %ghost %{_sysconfdir}/openvswitch/system-id.conf
%defattr(-,root,root)
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/openvswitch
%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
%config(noreplace) %{_sysconfdir}/logrotate.d/openvswitch
%{_unitdir}/openvswitch.service
%{_unitdir}/ovsdb-server.service
%{_unitdir}/ovs-vswitchd.service
%{_unitdir}/ovs-delete-transient-ports.service
%{_datadir}/openvswitch/scripts/openvswitch.init
%{_datadir}/openvswitch/scripts/ovs-check-dead-ifs
%{_datadir}/openvswitch/scripts/ovs-lib
%{_datadir}/openvswitch/scripts/ovs-save
%{_datadir}/openvswitch/scripts/ovs-vtep
%{_datadir}/openvswitch/scripts/ovs-ctl
%{_datadir}/openvswitch/scripts/ovs-kmod-ctl
%{_datadir}/openvswitch/scripts/ovs-systemd-reload
%config %{_datadir}/openvswitch/local-config.ovsschema
%config %{_datadir}/openvswitch/vswitch.ovsschema
%config %{_datadir}/openvswitch/vtep.ovsschema
%{_bindir}/ovs-appctl
%{_bindir}/ovs-dpctl
%{_bindir}/ovs-ofctl
%{_bindir}/ovs-vsctl
%{_bindir}/ovsdb-client
%{_bindir}/ovsdb-tool
%{_bindir}/ovs-pki
%{_bindir}/vtep-ctl
%{_libdir}/*.so.*
%{_sbindir}/ovs-vswitchd
%{_sbindir}/ovsdb-server
%{_mandir}/man1/ovsdb-client.1*
%{_mandir}/man1/ovsdb-server.1*
%{_mandir}/man1/ovsdb-tool.1*
%{_mandir}/man5/ovsdb.5*
%{_mandir}/man5/ovsdb.local-config.5*
%{_mandir}/man5/ovsdb-server.5.*
%{_mandir}/man5/ovs-vswitchd.conf.db.5*
%{_mandir}/man5/vtep.5*
%{_mandir}/man7/ovsdb-server.7*
%{_mandir}/man7/ovsdb.7*
%{_mandir}/man7/ovs-actions.7*
%{_mandir}/man7/ovs-fields.7*
%{_mandir}/man8/vtep-ctl.8*
%{_mandir}/man8/ovs-appctl.8*
%{_mandir}/man8/ovs-ctl.8*
%{_mandir}/man8/ovs-dpctl.8*
%{_mandir}/man8/ovs-kmod-ctl.8.*
%{_mandir}/man8/ovs-ofctl.8*
%{_mandir}/man8/ovs-pki.8*
%{_mandir}/man8/ovs-vsctl.8*
%{_mandir}/man8/ovs-vswitchd.8*
%{_mandir}/man8/ovs-parse-backtrace.8*
%{_udevrulesdir}/91-vfio.rules
%doc LICENSE NOTICE README.rst NEWS rhel/README.RHEL.rst
%ifarch %{dpdkarches}
%doc %{dpdkdir}/README.DPDK-PMDS
%attr(750,openvswitch,hugetlbfs) %verify(not owner group) /var/log/openvswitch
%else
%attr(750,openvswitch,openvswitch) %verify(not owner group) /var/log/openvswitch
%endif
/var/lib/openvswitch
%ghost %attr(755,root,root) %verify(not owner group) %{_rundir}/openvswitch
%{_datadir}/openvswitch/bugtool-plugins/
%{_datadir}/openvswitch/scripts/ovs-bugtool-*
%{_bindir}/ovs-dpctl-top
%{_sbindir}/ovs-bugtool
%{_mandir}/man8/ovs-dpctl-top.8*
%{_mandir}/man8/ovs-bugtool.8*
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} < 29)
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%endif
%{_sysusersdir}/openvswitch.conf
%ifarch %{dpdkarches}
%{_sysusersdir}/openvswitch-hugetlbfs.conf
%endif

%if %{with ipsec}
%files ipsec
%{_datadir}/openvswitch/scripts/ovs-monitor-ipsec
%{_unitdir}/openvswitch-ipsec.service
%endif

%changelog
* Thu Apr 03 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-62
- Merging upstream branch-3.4 [RH git: c0ca1fbb67]
    Commit list:
    d21e097280 ovsdb: raft: Fix cluster break down on leaving with some nodes down. (FDP-662)
    36eb236a65 ovsdb: raft: Add debug logs for role transition.
    e6d34d7bac ovsdb: raft: Fix multitasking overrun warning when there is no leader.


* Thu Apr 03 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-61
- Merging upstream branch-3.4 [RH git: 154cb1b182]
    Commit list:
    9101ec5163 python: Disable check for globals with never reassigned names (F824).
    45248dcaee checkpatch: Fix checkpatch's check-authors-file option in CirrusCI.
    a35a205323 ofproto-dpif: Fix spelling in comments and the support field macro.
    f8de001d89 checkpatch.py: Don't run subject checks in source-file mode.
    9cbf1ebe88 checkpatch: Add new check-authors-file option to checkpatch.py.
    6a7697d7d6 rhel/systemd: Change owner recursively and also on /etc/openvswitch.


* Wed Mar 26 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-60
- Merging upstream branch-3.4 [RH git: 55f93df13a]
    Commit list:
    26c5dd903e tests: ovsdb-idl: Fix flaky insert and delete tests.
    3b0d2669f0 python: stream: Fix unlink attempt for ptcp IP address.


* Fri Mar 21 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-59
- Merging upstream branch-3.4 [RH git: c46ca93c8b]
    Commit list:
    9acd2c0e8c ofproto-dpif: Fix dp_hash mapping after select group modification. ()


* Tue Mar 18 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-58
- Merging redhat subtree [RH git: d9b4e57798]
    Commit list:
    1f4be55a70 Use usermod to add hugetlbfs group to openvswitch if rpm doesn't support it


* Tue Mar 18 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-57
- Merging upstream branch-3.4 [RH git: ffadb877ce]
    Commit list:
    fef54350b6 tests: Disable rate limiting for tests parsing flow dumps from logs. ()


* Thu Mar 13 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-56
- Merging upstream branch-3.4 [RH git: 8feef886ea]
    Commit list:
    9285574887 tests: Fix 'ICMP related with SNAT' test case in offload scenario.
    2ebc68225c github: Get sparse from the official GitHub mirror.


* Fri Feb 28 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-55
- Merging upstream branch-3.4 [RH git: 682d47e755]
    Commit list:
    fa3585bc5f python: ovsdb-idl: Fix persist_uuid references.
    239fa55379 python: ovsdb-idl: Handle inserts w/o changes.


* Thu Feb 27 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-54
- Merging upstream branch-3.4 [RH git: d7abaf0721]
    Commit list:
    4395522770 Prepare for 3.4.3.
    5044a732e7 Set release date for 3.4.2.


* Wed Feb 26 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-53
- Merging upstream branch-3.4 [RH git: d96666c0b5]
    Commit list:
    515ba059f5 ofproto-dpif-xlate: Fix source IP lookup for non-bridge ports.


* Tue Feb 25 2025 Timothy Redaelli <tredaelli@redhat.com> - 3.4.0-52
- Add include.mk [RH git: 68e9fb2841]


* Tue Feb 25 2025 Timothy Redaelli <tredaelli@redhat.com> - 3.4.0-51
- Use symlink for README.rst [RH git: d431d15c5a]


* Tue Feb 25 2025 Timothy Redaelli <tredaelli@redhat.com> - 3.4.0-50
- Add 'redhat/' from commit '48fbd3b1cdb21757859dd27b51d71f0e01145222' [RH git: c229aeb560]
    git-subtree-dir: redhat
    git-subtree-mainline: 8773938372ce0ddd7642e393f4f2b280e5b2eb44
    git-subtree-split: 48fbd3b1cdb21757859dd27b51d71f0e01145222


* Tue Feb 25 2025 Timothy Redaelli <tredaelli@redhat.com> - 3.4.0-49
- Remove redhat/ [RH git: 8773938372]


* Tue Feb 18 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-48
- Merging dpdk subtree [RH git: 160c386e13]
    Commit list:
    0835a3db48 Merge tag 'v23.11.3' into 23.11
    c66daa12e7 version: 23.11.3
    b8e7797c11 net/virtio: fix Rx checksum calculation
    39bcde2d05 Revert "test/bonding: fix loop on members" ()
    7715edd977 power: fix log message when checking lcore ID
    425f5c7785 log: remove per line log helper
    67b9d0a29a version: 23.11.3-rc1
    c6222d018c rcu: fix implicit conversion in bit shift
    aca2600bac devtools: fix check of multiple commits fixed at once
    3f0cc8e583 doc: correct definition of stats per queue feature
    c56601621d app/testpmd: avoid potential outside of array reference
    d04a9ee164 app/testpmd: remove redundant policy action condition
    8a40df7196 test/eal: fix lcore check
    efa612cc5a test/eal: fix loop coverage for alignment macros
    cdb7df2917 test/event: avoid duplicate initialization
    d7e1948e49 test/security: fix IPv6 extension loop
    24327bf071 test/bonding: fix MAC address comparison
    cdf2912166 test/bonding: fix loop on members
    3d235f9cd4 pcapng: avoid potential unaligned data
    4e8254bf88 net/txgbe: fix a mass of interrupts
    e6339f0cab vhost: fix deadlock in Rx async path
    2ea75ee333 net/mlx5: fix shared Rx queue control release
    8d25cec04e app/testpmd: fix aged flow destroy
    e7a3a7d8c4 member: fix choice of bucket for displacement
    bc468700b4 app/procinfo: fix leak on exit
    e5180d0546 net/e1000/base: fix fallthrough in switch
    545d0c7dc5 common/dpaax/caamflib: enable fallthrough warnings
    31057c4fa6 net/i40e: check register read for outer VLAN
    db0eb33a6a net/iavf: add segment-length check to Tx prep
    347fa26942 bus/dpaa: fix lock condition during error handling
    3f018be5c5 net/mlx5: fix miniCQEs number calculation
    56ed7562cc net/mlx5: fix Rx queue reference count in flushing flows
    2168fb3f24 net/mlx5: fix default RSS flows creation order
    12bdfdbf01 common/mlx5: fix misalignment
    c86614bf2e net/mlx5: fix Rx queue control management
    8ef65f53eb net/mlx5: fix counter query loop getting stuck
    847c1bf789 net/mlx5/hws: fix allocation of STCs
    2f5821b3e7 net/mlx5: fix shared queue port number in vector Rx
    2f4b5d1426 common/mlx5: fix error CQE handling for 128 bytes CQE
    7f6b403c06 net/dpaa2: remove unnecessary check for null before free
    366c6b75e2 eventdev: fix possible array underflow/overflow
    dd6f41e09e examples/l2fwd-event: fix spinlock handling
    c761f2a838 net/cnxk: fix build on Ubuntu 24.04
    2ac522b91b common/cnxk: fix build on Ubuntu 24.04
    bacffdd59e net/bnx2x: fix duplicate branch
    fa00f7eb99 net/bnx2x: fix possible infinite loop at startup
    8080a3eb46 net/bnx2x: fix always true expression
    324925feea net/bnx2x: remove dead conditional
    5389d19ae9 net/bnxt: fix bad action offset in Tx BD
    17c6715f6c net/bnxt: fix TCP and UDP checksum flags
    4c1ae73212 net/bnxt: fix reading SFF-8436 SFP EEPROMs
    3b94bef6cd net/bnxt/tf_core: fix slice count in case of HA entry move
    d0c86aba09 net/bnxt/tf_core: fix Thor TF EM key size check
    9df7f2642d net/bnxt/tf_core: fix TCAM manager data corruption
    31a6d07adb net/bnxt/tf_core: fix WC TCAM multi-slice delete
    9e0f8e220f net/cpfl: fix forwarding to physical port
    ee03528a9d net/igc: fix Rx buffers when timestamping enabled
    57a39baf83 crypto/qat: fix ECDSA session handling
    fe1d9398be crypto/qat: fix modexp/inv length
    378e2300c1 test/crypto: fix synchronous API calls
    bbfd6cdd6b crypto/openssl: fix potential string overflow
    3b1fe8a417 baseband/acc: fix ring memory allocation
    8ee3e2a2ab event/octeontx: fix possible integer overflow
    f388f8a755 net/hns3: fix fully use hardware flow director table
    6603e0a887 net/hns3: fix error code for repeatedly create counter
    f9de7c177b net/vmxnet3: support larger MTU with version 6
    728b42e03a net/vmxnet3: fix potential out of bounds stats access
    3490d4e57c net/ngbe: restrict configuration of VLAN strip offload
    7a8481b344 net/ngbe: fix interrupt lost in legacy or MSI mode
    a00742dc65 net/ngbe: reconfigure more MAC Rx registers
    d387ad6d3a net/ngbe: fix driver load bit to inform firmware
    c8a526e4aa net/txgbe: fix driver load bit to inform firmware
    b636e174f9 net/txgbe: remove outer UDP checksum capability
    5efb2e5375 net/txgbe: fix VF-PF mbox interrupt
    9028f6687e net/txgbe: fix SWFW mbox
    3763c93479 net/hns3: remove ROH devices
    45b60a7435 net/vmxnet3: fix crash after configuration failure
    c6ad6ce36d net/netvsc: force Tx VLAN offload on 801.2Q packet
    dcc46f0e5f examples/ntb: check info query return
    f984d9801f test/bonding: remove redundant info query
    50aa17be6d examples/l3fwd: fix read beyond boundaries
    1ad8946112 examples/l3fwd-power: fix options parsing overflow
    57735df5fa net/dpaa2: fix memory corruption in TM
    690a4466f4 bus/fslmc: fix Coverity warnings in QBMAN
    3a06ee1e70 app/dumpcap: remove unused struct array
    67c2018ae1 net/mlx5: fix indirect list flow action callback invocation
    fc9a001f1d net/mlx5: fix reported Rx/Tx descriptor limits
    8d1138af4d net/mlx5: fix SWS meter state initialization
    c5b4c3ecad net/mlx5: fix non-template flow action validation
    b6ca715f56 net/mlx5: fix SQ flow item size
    1fca4f8bf1 net/mlx5/hws: fix range definer error recovery
    ffaa641b8f net/mlx5: fix GRE flow item translation for root table
    5eac1e6ff0 net/mlx5: fix memory leak in metering
    158ea9b655 eal/unix: optimize thread creation
    53b225e96b net/mlx5: fix Tx tracing to use single clock source
    9af26e2cde net/mlx5: fix real time counter reading from PCI BAR
    367c6c9c84 net/mlx5: fix trace script for multiple burst completion
    e594df339a crypto/openssl: fix 3DES-CTR with big endian CPUs
    5301879859 common/cnxk: fix double free of flow aging resources
    e26531c225 net/mvneta: fix possible out-of-bounds write
    d30bef9034 net/ixgbe: fix link status delay on FreeBSD
    d366bfb9c8 net/ice: detect stopping a flow director queue twice
    78b0870687 net/hns3: register VLAN flow match mode parameter
    8d0ca45d12 net/hns3: restrict tunnel flow rule to one header
    379d498833 net/netvsc: fix using Tx queue higher than Rx queues
    c7073bd24e 23.11.3-rc1
    45d48356e5 net/ionic: fix build with Fedora Rawhide
    1afa4c7c5e power: fix mapped lcore ID
    cdeda6ffe8 net/gve/base: fix build with Fedora Rawhide
    8844b427e8 dmadev: fix potential null pointer access
    a0607f5fb0 net/nfp: do not set IPv6 flag in transport mode
    d21d489fad net/nfp: notify flower firmware about PF speed
    886b99e9fa hash: fix thash LFSR initialization
    1f89198cfb build: remove version check on compiler links function
    44ba0b17ea net/mlx5: fix flex item header length field translation
    0645f6587a net/mlx5: fix non full word sample fields in flex item
    39c058f69c net/mlx5: fix next protocol validation after flex item
    07b84c0ed3 app/testpmd: remove flex item init command leftover
    be6e70f4b0 net/mlx5: fix number of supported flex parsers
    3f7bd80b7e net/mlx5: fix flex item tunnel mode
    01d6deac1d net/mlx5: add flex item query for tunnel mode
    0a64d025f6 net/mlx5/hws: fix flex item as tunnel header
    57d7ef4bd1 net/mlx5: workaround list management of Rx queue control
    c5b4422ac6 net/iavf: preserve MAC address with i40e PF Linux driver
    55b382e481 net/ice/base: fix VLAN replay after reset
    bf928774cc net/ice/base: add bounds check
    5325a17d8f net/pcap: fix blocking Rx
    23918a6a09 net/nfp: fix pause frame setting check
    732636cea5 net/nfp: fix link change return value
    fe1c8a18d1 net/hns3: verify reset type from firmware
    1660095be0 ethdev: verify queue ID in Tx done cleanup
    80d2fcc130 net/tap: restrict maximum number of MP FDs
    a228e595c1 net/memif: fix buffer overflow in zero copy Rx
    1766e0a61a net/gve: add IO memory barriers before reading descriptors
    d4bf7fd4b3 net/gve: fix refill logic causing memory corruption
    e6a3bb2869 net/nfp: fix representor port link status update
    be3892c592 net/nfp: fix type declaration of some variables
    b6bf4f5532 net/gve: always attempt Rx refill on DQ
    47d8a13a51 net/gve: fix mbuf allocation memory leak for DQ Rx
    07fb7df112 net/dpaa: fix reallocate mbuf handling
    bc069f0864 bus/dpaa: fix the fman details status
    c9c31ad42f bus/dpaa: fix VSP for 1G fm1-mac9 and 10
    bc23744d31 net/dpaa: fix typecasting channel ID
    d8653104f8 bus/dpaa: fix PFDRs leaks due to FQRNIs
    aaf4108fc3 ethdev: fix overflow in descriptor count
    07e7664545 net/hns3: fix dump counter of registers
    9691b735d0 net/hns3: remove some basic address dump
    423cac5f35 net/ena: revert redefining memcpy
    a050ba7ffe net/mana: support rdma-core via pkg-config
    43526bd598 net/pcap: set live interface as non-blocking
    d5a5ea31bb app/testpmd: remove unnecessary cast
    d82a275bd9 net/tap: avoid memcpy with null argument
    661aa0b6e7 net/gve: fix Tx for chained mbuf
    8a558580d8 net/gve: fix queue setup and stop
    e6295c5087 common/idpf: fix AVX-512 pointer copy on 32-bit
    19ba29791a net/iavf: fix AVX-512 pointer copy on 32-bit
    5bbf365cc9 net/ice: fix AVX-512 pointer copy on 32-bit
    ea5a85fc65 net/i40e: fix AVX-512 pointer copy on 32-bit
    ef1ec2ea1e net/iavf: delay VF reset command
    066aae50ee net/i40e/base: fix loop bounds
    abd0416c81 net/i40e/base: fix unchecked return value
    fc6a0dc44c net/i40e/base: fix repeated register dumps
    59d2c7c064 net/i40e/base: fix DDP loading with reserved track ID
    e3abeff288 net/i40e/base: fix blinking X722 with X557 PHY
    190f37ff8e net/i40e/base: add missing X710TL device check
    a9e11044c0 net/i40e/base: fix misleading debug logs and comments
    915830f032 net/i40e/base: fix setting flags in init function
    fa2ad7b33c net/ixgbe/base: fix unchecked return value
    ce72043138 net/ice/base: fix iteration of TLVs in Preserved Fields Area
    97b84ba5e9 net/ice/base: fix link speed for 200G
    49c494431a net/cpfl: fix parsing protocol ID mask field
    21d264149c net/iavf: fix crash when link is unstable
    e4a7cb42dc net/cpfl: add checks for flow action types
    c93b6d6b2d net/e1000: fix link status crash in secondary process
    ac3339a7ce fib: fix AVX512 lookup
    bc578c07f0 vhost: restrict set max queue pair API to VDUSE
    1048dc138b net/virtio-user: reset used index counter
    13406e37f9 vdpa/nfp: fix reconfiguration
    fe6e2ce164 vdpa/nfp: fix hardware initialization
    75cf78c0af vdpa: update used flags in used ring relay
    6e3cb080ec vhost: fix offset while mapping log base address
    b9c33e6227 baseband/acc: fix soft output bypass RM
    015973002b baseband/acc: fix access to deallocated mem
    149d6cee55 common/cnxk: fix IRQ reconfiguration
    2151056d7a common/cnxk: fix base log level
    9193f9aaec event/cnxk: fix OOP handling in event mode
    da82470018 net/cnxk: fix OOP handling for inbound packets
    c79d3d3f9e common/cnxk: fix CPT HW word size for outbound SA
    b4d9080615 common/cnxk: fix inline CTX write
    7ad2841fe8 common/cnxk: fix MAC address change with active VF
    b07c1fbe16 event/cnxk: fix Rx timestamp handling
    47d7010639 net/cnxk: fix Rx offloads to handle timestamp
    44a397a33b net/cnxk: fix Rx timestamp handling for VF
    181e17a8ce ml/cnxk: fix handling of TVM model I/O
    0f68a40858 app/dumpcap: fix handling of jumbo frames
    92040c569e pcapng: fix handling of chained mbufs
    11ac84c58a fib6: add runtime checks in AVX512 lookup
    f9cb3c9d11 power: enable CPPC
    2b19a7499a net/nfb: fix use after free
    037b235bde examples/vhost: fix free function mismatch
    0fc3555488 raw/ifpga: fix free function mismatch in interrupt config
    57d0cbadba raw/ifpga/base: fix use after free
    6ed76c1fb7 net/sfc: fix use after free in debug logs
    3e0f595521 net/nfp: fix double free in flow destroy
    9667b34853 net/e1000: fix use after free in filter flush
    c24dc6acb5 net/cpfl: fix invalid free in JSON parser
    e794faf1e5 net/cnxk: fix use after free in mempool create
    d8502a35fa event/cnxk: fix free function mismatch in port config
    5fe3dbe571 dma/idxd: fix free function mismatch in device probe
    c879fa42df crypto/bcmfs: fix free function mismatch
    02197bc242 common/idpf: fix use after free in mailbox init
    10f467409f common/qat: fix use after free in device probe
    bd33ab9160 baseband/la12xx: fix use after free in modem config
    c890f365b6 bpf: fix free function mismatch if convert fails
    77d2cb36a6 examples/ipsec-secgw: fix dequeue count from cryptodev
    023d3c4a2b crypto/scheduler: fix session size computation
    16c50a2885 dev: fix callback lookup when unregistering device
    a5680bcdb4 common/dpaax/caamflib: fix PDCP SNOW-ZUC watchdog
    26befc8aee crypto/dpaa2_sec: fix memory leak
    97d5f9eedb examples/eventdev: fix queue crash with generic pipeline
    2d4b832135 test/event: fix target event queue
    0786b20a56 test/event: fix schedule type
    058c13be8d eal/x86: fix 32-bit write combining store
    e56ba1eea6 drivers: remove redundant newline from logs
    1d5ac7180a bus/vdev: revert fix devargs in secondary process


* Mon Feb 17 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-47
- Merging upstream branch-3.4 [RH git: fc3ab7bd76]
    Commit list:
    83034418bf tests: Use correct arguments to curl.
    a1f23e09f9 dpif-netdev: Fix Auto Load Balance debug log. (FDP-1145)


* Thu Feb 13 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-46
- Merging upstream branch-3.4 [RH git: af23459b2a]
    Commit list:
    4925ac2296 miniflow_extract: Push ct_tp_{src, dst} for later frags. (FDP-124)


* Wed Feb 12 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-45
- Merging upstream branch-3.4 [RH git: 57d3e153cf]
    Commit list:
    f142ba5868 ovsdb-server: Do not use filename after free. (FDP-1118)


* Mon Feb 10 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-44
- Merging upstream branch-3.4 [RH git: fafb38cff7]
    Commit list:
    a8f5a97999 netdev-vport: Ignore ipsec_ tunnel option prefix for all tunnels. (FDP-797)
    d386b55887 ofproto-dpif-xlate: Fix memory leak in xlate_generic_encap_action().


* Fri Feb 07 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-43
- Merging upstream branch-3.4 [RH git: 9670a5b7b2]
    Commit list:
    1198632902 github: Update fedora image to 41.


* Thu Feb 06 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-42
- Merging upstream branch-3.4 [RH git: a79a343588]
    Commit list:
    f72cf70e56 fedora: Don't generate network-scripts-openvswitch for ver > 40.


* Fri Jan 31 2025 Kevin Traynor <ktraynor@redhat.com> - 3.4.0-41
- redhat: update ovsci Jenkins URL [RH git: a5660fc459]
    Signed-off-by: Kevin Traynor <ktraynor@redhat.com>


* Wed Jan 29 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-40
- Merging upstream branch-3.4 [RH git: da22876c68]
    Commit list:
    acc1e93e29 netdev-offload-tc: Fix ignore of dl type mask when installing flows. (FDP-1114)


* Fri Jan 24 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-39
- Merging upstream branch-3.4 [RH git: 956e0b7549]
    Commit list:
    2b7de35f08 dpdk: Use DPDK 23.11.3 release for OVS 3.4.


* Thu Jan 23 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-38
- Merging upstream branch-3.4 [RH git: 04a798dd77]
    Commit list:
    9e07a69bbb ofproto-macros.at: Fix hex matching in the strip_recird() macro.


* Mon Jan 20 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-37
- Merging upstream branch-3.4 [RH git: 83fc0be6e7]
    Commit list:
    318c1cd977 ofp-ct: Add missing struct declaration.


* Fri Jan 17 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-36
- Merging upstream branch-3.4 [RH git: 763e1e5f2c]
    Commit list:
    6022b55b62 docs: Add tunnel support to TSO GRE documentation.


* Thu Jan 16 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-35
- Merging upstream branch-3.4 [RH git: 76f2ce3983]
    Commit list:
    6c77226a92 rhel, debian: Add missing restart policy to ipsec service.
    c93755a782 rhel, debian: Fix systemd monitoring wrong pid for ovs-monitor-ipsec.


* Wed Jan 15 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-34
- Merging upstream branch-3.4 [RH git: 87fc234aa3]
    Commit list:
    7aa5f4270f dpif-netdev: Modify code comments for function parse_tcp_flags.
    4727d139bd ipf: Fix the over-sized reassembly.


* Tue Jan 14 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-33
- Merging upstream branch-3.4 [RH git: 83a4a02a37]
    Commit list:
    8c2bf8bff9 debian: Let *-ctl handle runtime directory.
    29dddea095 debian: Use PIDFile with systemd.
    308b441a12 debian: Add X-Python3-Version stanza.
    860b6f9858 debian: Drop shlibs:Depends macro for -ipsec.
    9ac8b0fc0e debian: Drop python3:Depends macro for -vtep.


* Tue Jan 14 2025 Timothy Redaelli <tredaelli@redhat.com> - 3.4.0-32
- pkgtool: OVS_SHA_REF should not be mandatory [RH git: 8639c9d8a6]


* Fri Jan 10 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-31
- Merging upstream branch-3.4 [RH git: 45195f5432]
    Commit list:
    80cccfbdd3 ovsdb: Fix asan warning on ovsdb fatal errors.


* Thu Jan 09 2025 Timothy Redaelli <tredaelli@redhat.com> - 3.4.0-30
- pkgtool: escape %% in changelog [RH git: 575ff3c7cf]


* Thu Jan 09 2025 Timothy Redaelli <tredaelli@redhat.com> - 3.4.0-29
- template: use %%patch -P0 instead of %%patch0 [RH git: 6be4f8029a]


* Thu Jan 09 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-28
- Merging upstream branch-3.4 [RH git: ae855601ab]
    Commit list:
    034b40fbb8 netdev-tc-offloads: Don't offload header modification on ip fragments. (FDP-545)


* Fri Dec 13 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-27
- Merging upstream branch-3.4 [RH git: 9cfbb9a33d]
    Commit list:
    5346c14b9f m4: Fix check for Python 3.6 version.


* Fri Dec 13 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-26
- Merging upstream branch-3.4 [RH git: 4f020a4eb1]
    Commit list:
    84a98a8ba4 ofproto: Fix default pmd_id for ofproto/detrace.
    65efbaa56a github: Skip clang-analyze when reference generation fails.


* Thu Dec 12 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-25
- Merging upstream branch-3.4 [RH git: 513b808a85]
    Commit list:
    069f5a7763 netdev-dpdk: Restore outer UDP checksum for Intel nics.


* Wed Dec 11 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-24
- Merging upstream branch-3.4 [RH git: 99590fdaef]
    Commit list:
    acee757306 cirrus: Update to FreeBSD 14.2 and 13.4.
    eb98e20da3 bridge: Fix log spam about prefixes.


* Mon Dec 02 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-23
- Merging upstream branch-3.4 [RH git: 222ad449f6]
    Commit list:
    a234629c33 netdev: Always clear struct ifreq before ioctl.
    118b4f2076 netdev-native-tnl: Fix use of uninitialized RSS hash.
    49d8d3066c tests: Use OVS_CHECK_XT6 for all applicable IPv6 tests.
    8886c64c1f tests: Use OVS_CHECK_XT for all applicable IPv4 tests.
    985f7ee313 classifier: Fix the fieldspec comment in the prefix tracking section.
    07720bc3f6 tests: Handle marks using nft if available.
    f3de3ab1b6 tests: Add nft support to ADD_EXTERNAL_CT.
    5931c6feb7 tests: Add nft accept support.
    e4d76aacd9 ovs-macros.at: Correctly delete iptables rule on_exit.
    2cdd886fc0 system-traffic: Do not rely on conncount for already tracked packets. (FDP-708)


* Mon Dec 02 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-22
- Merging upstream branch-3.4 [RH git: 9f3c002b41]
    Commit list:
    2463a1bf90 system-traffic: Fix syntax errors in FTP and IPv6 curl calls.


* Fri Nov 29 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-21
- Merging upstream branch-3.4 [RH git: ac163d63af]
    Commit list:
    77e82fa315 ovsdb-idl: Fix use of uninitialized datum for graph consistency check.
    fb1dad5be1 db-ctl-base: Fix uninitialized datum fields while checking conditions.
    9bda0df40e ovsdb-types: Fix use of uninitialized reference type.
    3ed582f4a8 ofproto-dpif-upcall: Fix use of uninitialized missed dumps counter.
    fcc8c2a917 ovs-vsctl, vtep-ctl: Silence memory sanitizer warning for longindex.
    76c3deb141 tests: multipath: Fix use of uninitialized wildcards.
    b359f1cf78 stream: replay: Fix potential NULL dereference on write failure.
    4d8155a5c1 ofp-actions: Fix use of uninitialized padding in set-field.


* Fri Nov 29 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-20
- Merging upstream branch-3.4 [RH git: 6ad38fd5b2]
    Commit list:
    6d02d8749c system-traffic: Standardize by replacing all wget instances with curl.
    a946d61f57 system-traffic: Replace wget with curl for negative and ftp tests.


* Wed Nov 27 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-19
- Merging upstream branch-3.4 [RH git: f70b3859b4]
    Commit list:
    87efb3c94b classifier: Increase the maximum number of prefixes (tries).
    5338f3ebeb Revert "github: Skip FTP SNAT orig tuple tests due to broken Ubuntu kernel."


* Mon Nov 18 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-18
- Merging dpdk subtree [RH git: 8d84b5400c]
    Commit list:
    78610a5530 net/iavf: delay VF reset command (FDP-957)


* Sat Nov 16 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-17
- Merging upstream branch-3.4 [RH git: 4def588584]
    Commit list:
    c25085f3d7 Prepare for 3.4.2.
    22a6b1110a Set release date for 3.4.1.


* Fri Nov 15 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-16
- Merging upstream branch-3.4 [RH git: ee85c64e6a]
    Commit list:
    fde8912b00 tests: Fix transient failure in ping6 header modify. ()
    5cefc11140 github: Build Libreswan v5.1 from sources.


* Mon Nov 11 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-15
- Merging upstream branch-3.4 [RH git: bbc8d4cbb1]
    Commit list:
    3d0246e3c3 ci: Update GitHub actions runner from Ubuntu 22.04 to 24.04.
    5c13ad0002 dpdk: Fix dpdk logs being split over multiple lines.


* Mon Nov 04 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-14
- Merging upstream branch-3.4 [RH git: d3616fbd62]
    Commit list:
    c6fc230a5d ipsec: libreswan: Reduce chances for crossing streams.
    e9f9e1eff5 tests: ipsec: Check that nodes can ping each other in the NxN test.
    94aeab7de2 tests: ipsec: Add NxN + reconciliation test.
    992e09e4d1 system-tests: Verbose cleanup of ports and namespaces.
    a5b5fce084 ipsec: Make command timeout configurable.
    49b066b5c4 ipsec: libreswan: Avoid monitor hanging on stuck ipsec commands. (FDP-846)
    729b4813c4 ipsec: libreswan: Try to bring non-active connections up.
    cb981fdb3e ipsec: libreswan: Reconcile missing connections periodically.
    f95b566dba ipsec: libreswan: Fix regexp for connections waiting on child SA.
    f1fcf08b37 ipsec: Add a helper function to run commands from the monitor.


* Wed Oct 30 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-13
- Merging upstream branch-3.4 [RH git: 41fa65f465]
    Commit list:
    77dc74395e meta-flow: Fix nw_frag mask while parsing from string.
    7e6a298c0e ci: Remove dependency on libpcap.
    b2d2ca05c0 github: Remove ASLR entropy workaround.
    b00d1115c5 bond: Always revalidate unbalanced bonds when active member changes. (FDP-845)
    d9f1469317 ofproto-dpif-upcall: Fix redundant mirror on metadata modification. (FDP-699)


* Thu Oct 24 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-12
- Merging dpdk subtree [RH git: 270d3c6ce7]
    Commit list:
    e8eb14e00d version: 23.11.2
    8401a3e84b version: 23.11.2-rc2
    50e50f1d99 net/ice/base: fix preparing PHY for timesync command
    7302cab07c net/nfp: fix firmware abnormal cleanup
    92c5aa4387 net/nfp: forbid offload flow rules with empty action list
    e9c4dbd5be crypto/openssl: make per-QP auth context clones
    729e0848b7 examples: fix port ID restriction
    3fc9eb2f4f examples: fix lcore ID restriction
    776c4e37ee doc: add baseline mode in l3fwd-power guide
    8437250f9f doc: fix DMA performance test invocation
    d01561713d doc: describe mlx5 HWS actions order
    1ef3097094 doc: add power uncore in API index
    09ccd86606 doc: fix mbuf flags
    613a4879b4 examples/ipsec-secgw: revert SA salt endianness
    8b87ae54ed doc: remove reference to mbuf pkt field
    938afb0ab2 examples: fix queue ID restriction
    80da81b6f9 net/ice/base: fix temporary failures reading NVM
    034f533709 net/hns3: fix uninitialized variable in FEC query
    5fa2084ac3 examples/l3fwd: fix crash on multiple sockets
    1708229729 examples/l3fwd: fix crash in ACL mode for mixed traffic
    bef8327055 bus/vdev: fix device reinitialization
    971d455e59 malloc: fix multi-process wait condition handling
    b53fb811c0 power: fix number of uncore frequencies
    52bf7488c3 app/pdump: handle SIGTERM and SIGHUP
    6bed8020a3 app/dumpcap: handle SIGTERM and SIGHUP
    eacf416207 dma/hisilicon: remove support for HIP09 platform
    a5375f4492 bus/pci: fix FD in secondary process
    c076f02992 bus/pci: fix UIO resource mapping in secondary process
    ca12727f09 app/testpmd: fix build on signed comparison
    b858eb7a55 net/gve: fix Tx queue state on queue start
    7ff9eeeb71 ethdev: fix device init without socket-local memory
    890b02b907 app/testpmd: add postpone option to async flow destroy
    fbd7ac3b83 net/netvsc: use ethdev API to set VF MTU
    e8746659b2 ethdev: fix GENEVE option item conversion
    e2b3b0a5d4 net/ark: fix index arithmetic
    7deaec6ac8 net/hns3: check Rx DMA address alignmnent
    6bf4a626e4 net/mlx5: fix disabling E-Switch default flow rules
    3b60ef3db6 common/mlx5: remove unneeded field when modify RQ table
    1988c32194 net/mlx5: fix uplink port probing in bonding mode
    07ad92c1a6 net/mlx5: fix end condition of reading xstats
    b7c9a02306 net/mlx5/hws: remove unused variable
    1163643a1e net/mlx5/hws: fix port ID on root item convert
    4a80ab31f0 net/mlx5/hws: fix deletion of action vport
    dcd02c715e net/mlx5/hws: fix check of range templates
    3c9aff8fbf net/mlx5/hws: fix memory leak in modify header
    85eeb293b3 net/mlx5: fix MTU configuration
    c1792007ff net/mlx5: fix Arm build with GCC 9.1
    a8331ab8b2 net/mlx5: fix shared Rx queue data access race
    15e2b0e736 net/ice: fix return value for raw pattern parsing
    17e800edd1 net/ice: fix memory leaks in raw pattern parsing
    8f23521ad7 common/cnxk: fix integer overflow
    a408bd0bcb crypto/qat: fix placement of OOP offset
    b2acb5218f test/crypto: fix modex comparison
    d308cefc96 test/crypto: fix asymmetric capability test
    adffcf4383 test/crypto: remove unused stats in setup
    4b0d806bab doc: fix typo in l2fwd-crypto guide
    0e19bfa703 crypto/qat: fix log message typo
    5d66d4a3f0 test/crypto: fix allocation comment
    9fef0db81b crypto/ipsec_mb: fix function comment
    c6111cb5fd crypto/qat: fix GEN4 write
    f707532cde net/nfp: fix disabling 32-bit build
    de0c58c4b8 doc: update AF_XDP device plugin repository
    811fcdf23a net/nfp: adapt reverse sequence card
    ea7085704a net/nfp: remove unneeded logic for VLAN layer
    4c45c694ca doc: update metadata description in nfp guide
    174b2b5a9a net/nfp: fix getting firmware version
    241976029a net/nfp: remove redundant function call
    c90d304f0e net/gve: fix RSS hash endianness in DQO format
    316baf3f0b net/ena: fix checksum handling
    ffba3914ad net/ena: fix return value check
    db4ca6f1cb net/ena: fix bad checksum handling
    5453c7a0b0 net/nfp: fix repeat disable port
    51d6936232 net/nfp: fix dereference of null pointer
    d0d759188e net/nfp: disable ctrl VNIC queues on close
    c22c079e1c net/ionic: fix mbuf double-free when emptying array
    2e84f93745 net/nfp: fix flow mask table entry
    8df473a653 net/nfp: fix allocation of switch domain
    2a50559bfd net/netvsc: fix MTU set
    e2ef427581 net/nfp: fix IPv6 TTL and DSCP flow action
    3762e1ed03 net/vmxnet3: fix init logs
    fdc5f6074b net/txgbe: fix Rx interrupt
    2dfb54ff33 net/ngbe: fix memory leaks
    638e12515a net/txgbe: fix memory leaks
    d0a84e43b3 net/ngbe: fix MTU range
    0fe77d1de3 net/txgbe: fix MTU range
    db50b74b3c net/ngbe: fix hotplug remove
    5de5204582 net/txgbe: fix hotplug remove
    6d224307f6 net/ngbe: keep PHY power down while device probing
    658060fffe net/ngbe: add special config for YT8531SH-CA PHY
    85bd339e19 net/txgbe: fix VF promiscuous and allmulticast
    ea62ead19d net/txgbe: reconfigure more MAC Rx registers
    55d8be2055 net/txgbe: restrict configuration of VLAN strip offload
    ed2250e120 net/txgbe: fix Tx hang on queue disable
    6ea637699a net/txgbe: fix flow filters in VT mode
    842a7baf9c net/txgbe: fix tunnel packet parsing
    708d5a261b net/mana: fix uninitialized return value
    e113512712 app/testpmd: fix parsing for connection tracking item
    11b6493c45 doc: remove empty section from testpmd guide
    f11711212c app/testpmd: handle IEEE1588 init failure
    e7f8c62dfc net/cpfl: fix 32-bit build
    ec9de9db2d net/cpfl: add checks on control queue messages
    39b2b4c7de common/idpf: fix PTP message validation
    e0f453462f common/idpf: fix flex descriptor mask
    bd5b88d172 net/ice/base: fix masking when reading context
    67a40ce4ef net/ice/base: fix board type definition
    5167b4d2d3 net/ice/base: fix potential TLV length overflow
    abd055ea63 net/ice/base: fix check for existing switch rule
    fddfbdbf49 net/ice/base: fix return type of bitmap hamming weight
    c9eae16d5e net/ice/base: fix GCS descriptor field offsets
    8bc9ae6b59 net/ice/base: fix size when allocating children arrays
    1257bf9a7c net/ice/base: fix sign extension
    2458257e56 net/ice/base: fix resource leak
    7a6c0e6212 net/ice/base: fix memory leak in firmware version check
    87d7cf4082 net/ice/base: fix pointer to variable outside scope
    aafeb830bc buildtools: fix build with clang 17 and ASan
    a4e8a4f488 fbarray: fix finding for unaligned length
    d88beb497f net/mlx5: fix start without duplicate flow patterns
    77231b2598 net/dpaa: forbid MTU configuration for shared interface
    d21248db89 bus/dpaa: remove redundant file descriptor check
    bb85c1fd72 common/dpaax: fix node array overrun
    90c9f938e5 common/dpaax: fix IOVA table cleanup
    0b4bc3a5d1 bus/dpaa: fix memory leak in bus scan
    d36efdb2cd bus/dpaa: fix bus scan for DMA devices
    daa0d9edd1 app/testpmd: fix help string of BPF load command
    7353cb767f dma/idxd: fix setup with Ubuntu 24.04
    f563086258 eal/linux: lower log level on allocation attempt failure
    8ccf607fad devtools: fix symbol listing
    997166395e fbarray: fix lookbehind ignore mask handling
    8baf379032 fbarray: fix lookahead ignore mask handling
    24869bf93c fbarray: fix incorrect lookbehind behavior
    5e66590575 fbarray: fix incorrect lookahead behavior
    427fa07238 examples/ipsec-secgw: fix SA salt endianness
    d0d02993de crypto/dpaa2_sec: fix event queue user context
    6e2def6ca9 crypto/dpaa_sec: fix IPsec descriptor
    b977583692 common/dpaax/caamflib: fix PDCP AES-AES watchdog error
    5089ef6c28 common/dpaax/caamflib: fix PDCP-SDAP watchdog error
    4af94ab6e2 crypto/openssl: set cipher padding once
    4f8c97e941 crypto/openssl: make per-QP cipher context clones
    ee88b9496c crypto/openssl: optimize 3DES-CTR context init
    eb6a1a85e6 crypto/openssl: fix GCM and CCM thread unsafe contexts
    cc8ca588a0 examples/fips_validation: fix dereference and out-of-bound
    9b3e235581 cryptodev: validate crypto callbacks from next node
    578ee20720 cryptodev: fix build without crypto callbacks
    fbb350108f crypto/cnxk: fix minimal input normalization
    7978b75d1b test/crypto: validate modex from first non-zero
    ede34a4359 app/crypto-perf: fix result for asymmetric
    7469762567 app/crypto-perf: remove redundant local variable
    e585a0db98 crypto/cnxk: fix ECDH public key verification
    6034788bd6 crypto/cnxk: fix out-of-bound access
    ea90bc49fc net/virtio-user: fix control queue allocation for non-vDPA
    15d3dfa07a baseband/la12xx: forbid secondary process
    f798848548 telemetry: fix connection parameter parsing
    713520f91d bpf: fix load hangs with six IPv6 addresses
    59523f029e bpf: fix MOV instruction evaluation
    c9071e44b7 mbuf: fix dynamic fields copy
    c13a819a44 graph: fix mcore dispatch walk
    777f0bc1a5 vdpa/sfc: remove dead code
    583796e298 dmadev: fix structure alignment
    d859544e45 common/cnxk: fix flow aging on application exit
    c343cb088f app/bbdev: fix interrupt tests
    0c99a3d922 app/bbdev: fix MLD output size computation
    179f1c6e6b app/bbdev: fix TB logic
    acdd88c4f9 build: use builtin helper for python dependencies
    edfa6a87c8 config: fix warning for cross build with meson >= 1.3.0
    151a54d0b6 v23.11.2-rc1
    61b7d1f4c1 doc: fix link to hugepage mapping from Linux guide
    0e68080faf telemetry: lower log level on socket error
    4fe42b5bd5 test/crypto: fix enqueue/dequeue callback case
    4dc08a4d14 test/crypto: fix RSA cases in QAT suite
    f1e088abb9 net/mlx5/hws: fix matcher reconnect
    db0c8afc11 net/mlx5: fix crash on counter pool destroy
    59e27c048f net/mlx5: support jump in meter hierarchy
    15d0fcf1ac net/mlx5: fix access to flow template operations
    7cc4f4359e net/mlx5: break flow resource release loop
    8f7a4c4861 net/mlx5: fix flow template indirect action failure
    0caa8332a4 net/mlx5: fix hash Rx queue release in flow sample
    5546ccbefe net/mlx5: fix indexed pool with invalid index
    c12bd3ffbf net/mlx5/hws: fix action template dump
    096734a9b5 net/mlx5/hws: set default miss when replacing table
    df8e365511 net/mlx5/hws: extend tag saving for match and jumbo
    9b84b09d4a net/mlx5/hws: add template match none flag
    8b2eb11323 net/mlx5/hws: fix spinlock release on context open
    3811ef8d25 net/mlx5/hws: fix function comment
    21c0e76d5a common/mlx5: fix PRM structs
    aec70880d8 net/mlx5/hws: decrease log level for creation failure
    b4d5b769a9 common/mlx5: fix unsigned/signed mismatch
    5405ea2f7a hash: fix RCU reclamation size
    2f62695370 bpf: disable on 32-bit x86
    61c4175079 graph: fix stats retrieval while destroying a graph
    e022af0b88 graph: fix ID collisions
    4541f5810c net/cnxk: fix promiscuous state after MAC change
    144a806a1b net/cnxk: fix outbound security with higher packet burst
    01d4a05a9f net/cnxk: update SA userdata and keep original cookie
    802a3a7d74 net/cnxk: fix extbuf handling for multisegment packet
    67a8e5ba52 common/cnxk: fix segregation of logs based on module
    c99b186412 common/cnxk: fix flow aging cleanup
    af85590165 net/cnxk: fix RSS config
    1e2d3032e2 net/ixgbe/base: fix PHY ID for X550
    b371343ddc net/ixgbe/base: fix 5G link speed reported on VF
    3d128f41b7 net/ixgbe/base: revert advertising for X550 2.5G/5G
    7ec2441a3e net/e1000/base: fix link power down
    4c8436297f net/ixgbe: do not create delayed interrupt handler twice
    f683115cef net/ixgbe: do not update link status in secondary process
    0fc2747f6c net/ice: fix VLAN stripping in double VLAN mode
    729144bdae net/fm10k: fix cleanup during init failure
    bb9096e474 net/iavf: fix VF reset when using DCF
    b6e445d0d4 eventdev/crypto: fix opaque field handling
    32c7c20981 event/sw: fix warning from useless snprintf
    614773e8c7 baseband/acc: fix memory barrier
    ac1bd05172 net/virtio: fix MAC table update
    eb821e0ed1 net/virtio-user: fix control queue allocation
    6e4de6f224 net/virtio-user: fix shadow control queue notification init
    1d824e440e net/virtio-user: fix control queue destruction
    2fdb8840ee vhost: cleanup resubmit info before inflight setup
    8c020a6f4d vhost: fix build with GCC 13
    1af612de7e hash: check name when creating a hash
    9616fce23b hash: fix return code description in Doxygen
    44bcfd6b38 net/nfp: fix xstats for multi PF firmware
    8bf40f1d11 app/testpmd: fix lcore ID restriction
    80c5c9789b net/iavf: remove outer UDP checksum offload for X710 VF
    1970a0ca45 net/i40e: fix outer UDP checksum offload for X710
    e8c2cccfbd net: fix outer UDP checksum in Intel prepare helper
    dda814c495 app/testpmd: fix outer IP checksum offload
    4d57f72a5b net/ice: fix check for outer UDP checksum offload
    c61b23292e net/axgbe: fix linkup in PHY status
    b7eddfc563 net/axgbe: delay AN timeout during KR training
    388f022054 net/axgbe: fix Tx flow on 30H HW
    e3632f6bbb net/axgbe: check only minimum speed for cables
    141a4ff6d5 net/axgbe: fix connection for SFP+ active cables
    4eda15db34 net/axgbe: fix SFP codes check for DAC cables
    d72913dcad net/axgbe: enable PLL control for fixed PHY modes only
    3cf40bf1c3 net/axgbe: disable RRC for yellow carp devices
    ec06a8c3d4 net/axgbe: disable interrupts during device removal
    a2be089e35 net/axgbe: update DMA coherency values
    17290bc90b net/axgbe: fix fluctuations for 1G Bel Fuse SFP
    a61b3c008a net/axgbe: reset link when link never comes back
    498a5720e3 net/axgbe: fix MDIO access for non-zero ports and CL45 PHYs
    dea5481a8f net/tap: fix file descriptor check in isolated flow
    c22f99f86c net/nfp: fix configuration BAR
    ab2e5cf865 net/nfp: fix resource leak in secondary process
    442ca8b2ec net/af_xdp: remove unused local statistic
    b0a4771394 net/af_xdp: fix stats reset
    fdda0d4d83 net/af_xdp: count mbuf allocation failures
    c6891273d3 net/af_xdp: fix port ID in Rx mbuf
    60f2e572ea doc: fix testpmd ring size command
    bd69f5a43d net/af_packet: align Rx/Tx structs to cache line
    e9da7f4655 net/vmxnet3: add missing register command
    e754c1c6d8 ethdev: fix strict aliasing in link up
    b1be619a77 net/af_xdp: fix multi-interface support for k8s
    3bbccce3a9 doc: fix AF_XDP device plugin howto
    02d2453afc net/hns3: disable SCTP verification tag for RSS hash input
    6e37e43fe3 net/hns3: fix variable overflow
    16a24e9f99 net/hns3: fix double free for Rx/Tx queue
    78e4da4546 net/hns3: fix Rx timestamp flag
    c491084749 net/hns3: fix offload flag of IEEE 1588
    beda536606 app/testpmd: fix indirect action flush
    dae924d0a2 net/bonding: fix failover time of LACP with mode 4
    453e0c281b net/nfp: fix representor port queue release
    83149f4fea latencystats: fix literal float suffix
    50b99c8b12 eal/windows: install sched.h file
    11af26df38 net/virtio-user: add memcpy check
    eb02060534 pcapng: add memcpy check
    2dd9223248 eal/unix: support ZSTD compression for firmware
    09e70301ee eal: fix type in destructor macro for MSVC
    338632b663 bus/pci: fix build with musl 1.2.4 / Alpine 3.19
    a6ec5765cf version: 23.11.1
    51783c9b60 version: 23.11.1-rc2
    152600d10e net/mlx5/hws: fix tunnel protocol checks
    67f3179f5c net/mlx5: fix rollback on failed flow configure
    750d393405 net/mlx5: fix async flow create error handling
    41c5baeffc net/mlx5/hws: fix port ID for root table
    cfa8a4cb90 net/ena/base: fix metrics excessive memory consumption
    a20a3c1129 dts: strip whitespaces from stdout and stderr
    abc6816134 examples/ipsec-secgw: fix typo in error message
    cf631810bf test/cfgfile: fix typo in error messages
    f48e923b46 test/power: fix typo in error message
    ed3a625fe6 doc: fix typo in packet framework guide
    e85092f875 doc: fix typo in profiling guide
    df1119d4a9 net/mlx5: fix sync flow meter action
    aeebcd33c0 net/mlx5/hws: fix memory access in L3 decapsulation
    0291a1f49e net/igc: fix timesync disable
    07fde8240d net/vmxnet3: ignore Rx queue interrupt setup on FreeBSD
    d2d309e5cf net/ena: fix mbuf double free in fast free mode
    f7d1b5cff3 app/testpmd: fix auto-completion for indirect action list
    4aa1a64204 net/nfp: fix uninitialized variable
    a5ac9baa7a doc: fix default IP fragments maximum in programmer guide
    f7909e3c75 examples/ipsec-secgw: fix Rx queue ID in Rx callback
    0a44e64c41 net/bnxt: fix number of Tx queues being created
    5a8ca987e9 net/mlx5: fix warning about copy length
    2864fd3102 net/mlx5: fix drop action release timing
    9aba4dee4d net/mlx5: fix age position in hairpin split
    fc12ccc047 net/mlx5: prevent ioctl failure log flooding
    8117b4b2f7 net/mlx5: fix flow configure validation
    b1749f6ed2 net/mlx5: fix template clean up of FDB control flow rule
    3735e8e88c net/mlx5/hws: fix direct index insert on depend WQE
    859bafedf3 net/mlx5: fix DR context release ordering
    9a9f0acac6 net/mlx5: fix IP-in-IP tunnels recognition
    c551015ebb net/mlx5: remove duplication of L3 flow item validation
    a8b06881d9 net/mlx5: fix meter policy priority
    78d38b5d67 net/mlx5: fix VLAN ID in flow modify
    f01fd28181 doc: update link to Windows DevX in mlx5 guide
    af41defcf7 net/mlx5: fix non-masked indirect list meter translation
    1994df02c9 net/mlx5: fix indirect action async job initialization
    7192f0ed82 net/mlx5: fix sync meter processing in HWS
    50eb03f8d3 net/mlx5: fix HWS meter actions availability
    fe697bbce3 net/hns3: support new device
    97089aa02e app/testpmd: fix error message for invalid option
    92c08367ea app/testpmd: fix burst option parsing
    6c2174ad80 app/testpmd: fix --stats-period option check
    0884b3bd36 net/nfp: fix initialization failure flow
    dd48153b15 net/nfp: fix switch domain free check
    aa850bad00 net/ena/base: restructure interrupt handling
    e1abac3de0 net/ena/base: limit exponential backoff
    2fa8497bd3 net/ena: fix fast mbuf free
    5f75adca7e net/nfp: fix IPsec data endianness
    bec3117648 net/nfp: fix getting firmware VNIC version
    5853ebb3b9 doc: add link speeds configuration in features table
    15952c71eb app/testpmd: fix async indirect action list creation
    166c5df810 doc: add traffic manager in features table
    cadb90f711 net/hns3: enable PFC for all user priorities
    72d3dfa9de crypto/qat: fix crash with CCM null AAD pointer
    90d0e13d7d examples/ipsec-secgw: fix cryptodev to SA mapping
    9796ac2ab8 build: pass cflags in subproject
    7105c8a299 net/virtio: fix vDPA device init advertising control queue
    587143897e examples/l3fwd: fix Rx queue configuration
    2f8836901c dts: fix smoke tests driver regex
    ce95b8c9cd examples/l3fwd: fix Rx over not ready port
    10296d5f50 examples/packet_ordering: fix Rx with reorder mode disabled
    e8dccbca30 test: do not count skipped tests as executed
    5c5df0f292 test: assume C source files are UTF-8 encoded
    de3976eb27 test/mbuf: fix external mbuf case with assert enabled
    ced51dd5ef config: fix CPU instruction set for cross-build
    6148604a43 bus/vdev: fix devargs in secondary process
    ef4c8a57f3 test: fix probing in secondary process
    272feb8eb9 net/mlx5: remove device status check in flow creation
    a10a65c396 net/mlx5: fix flow action template expansion
    0c31d1220f net/mlx5: fix counters map in bonding mode
    091234f3cb net/mlx5: fix flow counter cache starvation
    b90c42e4ff net/mlx5: fix parameters verification in HWS table create
    0198b11a11 net/mlx5: fix VLAN handling in meter split
    86c66608c2 net/mlx5/hws: enable multiple integrity items
    ca1084cd48 net/mlx5: fix HWS registers initialization
    527857d5c2 net/mlx5: fix connection tracking action validation
    1d65510ff6 net/mlx5: fix conntrack action handle representation
    a5d0545e5d net/mlx5: fix condition of LACP miss flow
    17f644b4a8 net/mlx5/hws: fix VLAN inner type
    99be466799 net/mlx5: prevent querying aged flows on uninit port
    bfa6cbba4c net/mlx5: fix error packets drop in regular Rx
    213cb88068 net/mlx5: fix use after free when releasing Tx queues
    a06ab8044a net/mlx5/hws: fix VLAN item in non-relaxed mode
    21d51e8848 net/mlx5/hws: check not supported fields in VXLAN
    b80ca5960e net/mlx5/hws: skip item when inserting rules by index
    2368f82fd8 doc: fix aging poll frequency option in cnxk guide
    630dbc8a92 net/cnxk: improve Tx performance for SW mbuf free
    37256aa1bf common/cnxk: fix possible out-of-bounds access
    9172348240 common/cnxk: remove dead code
    9cb9b9c8a0 common/cnxk: fix link config for SDP
    6f05d2d461 net/cnxk: fix mbuf fields in multi-segment Tx
    a6bd2f39c1 common/cnxk: fix mbox struct attributes
    e5450b2bba net/cnxk: add cookies check for multi-segment offload
    0e5159a223 net/cnxk: fix indirect mbuf handling in Tx
    6c6cd1fe53 common/cnxk: fix RSS RETA configuration
    f4c83ba01c net/cnxk: fix MTU limit
    3e73021b35 common/cnxk: fix Tx MTU configuration
    e71ac13a38 net/cnxk: fix buffer size configuration
    fbfaa5ae04 common/cnxk: remove CN9K inline IPsec FP opcodes
    b3ef799286 net/bnx2x: fix warnings about memcpy lengths
    2d11f389b0 net/cnxk: fix Rx packet format check condition
    8bc81d5447 common/cnxk: fix inline device pointer check
    dbdcd8bb85 net/ice: remove incorrect 16B descriptor read block
    72093d3d41 net/iavf: remove incorrect 16B descriptor read block
    542c8410cb net/i40e: remove incorrect 16B descriptor read block
    33b5bed057 net/ixgbe: increase VF reset timeout
    eefc0111de net/iavf: remove error logs for VLAN offloading
    2aa5a75750 net/ixgbevf: fix RSS init for x550 NICs
    a71de447a2 net/bnxt: fix null pointer dereference
    1d5bfd9fdf net/tap: fix traffic control handle calculation
    e9462a5690 net/tap: do not overwrite flow API errors
    4a1ffc9b02 app/testpmd: fix async flow create failure handling
    92ab2d6da2 app/testpmd: return if no packets in GRO heavy weight mode
    61ce57b13a net/mlx5: fix modify flex item
    4d1331e972 app/testpmd: fix flow modify tag typo
    c2d52df599 net/af_xdp: fix leak on XSK configuration failure
    b2dba501cf vhost: fix VDUSE device destruction failure
    af414b892d common/qat: fix legacy flag
    6cacd0e502 doc: fix typos in cryptodev overview
    14c38e2db1 app/crypto-perf: add missing op resubmission
    a1f1843146 app/crypto-perf: fix out-of-place mbuf size
    f0cfffc636 app/crypto-perf: fix copy segment size
    b2cd908926 eventdev/crypto: fix enqueueing
    e5ed464710 eventdev: fix Doxygen processing of vector struct
    2faf71417f eventdev: improve Doxygen comments on configure struct
    7721c9f498 test/event: fix crash in Tx adapter freeing
    524c60f422 event/dlb2: remove superfluous memcpy
    4e8d39a298 doc: fix configuration in baseband 5GNR driver guide
    b0b971bf66 23.11.1-rc1
    05bea47b81 app/testpmd: fix GRO packets flush on timeout
    cc670c7833 net/nfp: fix NFDk metadata process
    8e79562a0e net/nfp: fix NFD3 metadata process
    1f3f996269 net/mlx5: fix stats query crash in secondary process
    5982bea06b net/mlx5: fix GENEVE option item translation
    22653f6966 net/mlx5: remove GENEVE options length limitation
    06c494555f common/mlx5: fix query sample info capability
    10061b4047 common/mlx5: fix duplicate read of general capabilities
    1825629903 net/mlx5: fix GENEVE TLV option management
    c3eb862979 net/mlx5/hws: fix ESP flow matching validation
    d25716a8a0 net/mlx5: fix flow tag modification
    7c8f2e719a net/mlx5: fix jump action validation
    01c5db8d99 net/cnxk: fix aged flow query
    ecdb679c52 common/cnxk: fix VLAN check for inner header
    4f69dab88c common/cnxk: fix mbox region copy
    0e5798d30b net/thunderx: fix DMAC control register update
    874fd28866 net/cnxk: fix flow RSS configuration
    f047cea926 ml/cnxk: fix xstats calculation
    a77f545bd7 net/bnxt: fix deadlock in ULP timer callback
    d9e1762f07 net/bnxt: modify locking for representor Tx
    c26cb2a644 net/bnxt: fix backward firmware compatibility
    1fb50b8baa net/bnxt: fix speed change from 200G to 25G on Thor
    e1f8152ede net/bnxt: fix 50G and 100G forced speed
    3fa018b15a net/bnxt: fix array overflow
    c3ccbda492 net/netvsc: fix VLAN metadata parsing
    de2d362411 net: add macros for VLAN metadata parsing
    561a3f508f net/gve: fix DQO for chained descriptors
    de543e342a net/softnic: fix include of log library
    edaeda9ef7 net/memif: fix extra mbuf refcnt update in zero copy Tx
    c7b50f40e1 common/sfc_efx/base: use C11 static assert
    216918c28c net/mana: handle MR cache expansion failure
    6679de7a8f net/mana: fix memory leak on MR allocation
    3fb4840708 net/bonding: fix flow count query
    1ce60b941d net/ionic: fix device close
    9583f634f3 net/ionic: fix RSS query
    2ea5bde557 net/ionic: fix missing volatile type for cqe pointers
    49b4ce1f94 app/testpmd: fix crash in multi-process forwarding
    db4ba50b3a drivers/net: fix buffer overflow for packet types list
    7de2520f2d net/mana: prevent values overflow returned from RDMA layer
    84e9d93f57 net/nfp: free switch domain ID on close
    a581442d9b net/nfp: fix device resource freeing
    52bd57a03b net/nfp: fix device close
    c65a2bfc26 net/vmxnet3: fix initialization on FreeBSD
    edc0e91ffc app/testpmd: hide --bitrate-stats in help if disabled
    ec2260423e doc: add --latencystats option in testpmd guide
    e670d64d34 net/hns3: remove QinQ insert support for VF
    48fe88cb3c net/nfp: fix Rx descriptor
    e024c471f9 net/nfp: fix Rx memory leak
    cb1cef89c4 net/hns3: fix reset level comparison
    a3584fcde6 net/hns3: fix disable command with firmware
    48d9241bbd net/hns3: fix VF multiple count on one reset
    8abf8591dc net/hns3: refactor handle mailbox function
    1be4ad59be net/hns3: refactor send mailbox function
    f876981e54 net/hns3: refactor PF mailbox message struct
    c1c62366ed net/hns3: refactor VF mailbox message struct
    9cf299a873 net/memif: fix crash with Tx burst larger than 255
    01809245ba net/af_xdp: fix memzone leak on config failure
    c2a5c0d085 net/nfp: fix resource leak for VF
    ddeb9d64a9 net/nfp: fix resource leak for exit of flower firmware
    e65a677895 net/nfp: fix resource leak for exit of CoreNIC firmware
    09e1df883a net/nfp: fix resource leak for flower firmware
    02916557c1 net/nfp: fix resource leak for PF initialization
    1d53d5495b net/nfp: fix resource leak for CoreNIC firmware
    f2ee31d52c net/nfp: fix resource leak for device initialization
    8610d2715d ethdev: fix NVGRE encap flow action description
    d06a344524 doc: fix commands in eventdev test tool guide
    9350513462 test/event: skip test if no driver is present
    6ccd84cf16 event/cnxk: fix dequeue timeout configuration
    b7fd1f73fe app/crypto-perf: fix encrypt operation verification
    04d9dfd665 app/crypto-perf: fix data comparison
    dfc9d45365 app/crypto-perf: fix next segment mbuf
    8988726643 crypto/cnxk: fix CN9K ECDH public key verification
    ea096d3e48 common/cnxk: fix memory leak in CPT init
    f5d6c54154 examples/ipsec-secgw: fix width of variables
    96d48b5b40 cryptodev: remove unused extern variable
    e951bbbd18 vhost: fix memory leak in Virtio Tx split path
    19f0cf0927 vdpa/mlx5: fix queue enable drain CQ
    5eb1dd92dc vhost: fix deadlock during vDPA SW live migration
    33fbddf9a4 net/virtio: remove duplicate queue xstats
    c8e7cd6c6d vhost: fix virtqueue access check in vhost-user setup
    692a7a0034 vhost: fix virtqueue access check in VDUSE setup
    bbba917213 vhost: fix virtqueue access check in datapath
    c139df70dd net: fix TCP/UDP checksum with padding data
    c30a4f8b31 rcu: fix acked token in debug log
    94b20c14a6 rcu: use atomic operation on acked token
    8878a84e2e build: link static libs with whole-archive in subproject
    5e24d7f2de build: fix linker warnings about undefined symbols
    63241d7662 net/sfc: fix calloc parameters
    acad009eed net/nfp: fix calloc parameters
    238a03cdec net/bnx2x: fix calloc parameters
    e3ae3295ee common/mlx5: fix calloc parameters
    7c10528d68 rawdev: fix calloc parameters
    ad881b0db8 dmadev: fix calloc parameters
    9173abff75 eventdev: fix calloc parameters
    600e30b793 pipeline: fix calloc parameters
    5331b41382 examples/vhost: verify strdup return
    88f1c9af33 examples/qos_sched: fix memory leak in args parsing
    fbd04d26f3 test: verify strdup return
    c830d9e2af app/testpmd: verify strdup return
    8d5327fcfd app/dma-perf: verify strdup return
    fefe40a5ed app/crypto-perf: verify strdup return
    e0fd44c6ab app/pdump: verify strdup return
    1387327fa4 app/dumpcap: verify strdup return
    c6790ef542 net/nfp: verify strdup return
    2044a179a7 net/failsafe: fix memory leak in args parsing
    cedf721f24 event/cnxk: verify strdup return
    df74839ea1 dma/idxd: verify strdup return
    b4943e7a51 bus/vdev: verify strdup return
    82d4ba69f2 bus/fslmc: verify strdup return
    8c8e7aeb90 bus/dpaa: verify strdup return
    2feed5de50 eal: verify strdup return
    bb34c79bf4 doc: remove cmdline polling mode deprecation notice
    5f30c47cc5 eal/x86: add AMD vendor check for TSC calibration
    a9e8fc49d9 ci: update versions of actions in GHA
    d7a30d20c4 gro: fix reordering of packets
    b5c580913f telemetry: fix empty JSON dictionaries
    cbd1c165bb telemetry: fix connected clients count
    d7dc480432 app/graph: fix build reason
    7872a7b0bd build: fix reasons conflict
    54e4045c78 kernel/freebsd: fix module build on FreeBSD 14
    943de5c27e net/ice: fix memory leaks
    9aa2da4c02 net/iavf: fix crash on VF start
    0a72821dd9 net/iavf: fix no polling mode switching
    c321ba6a9d net/ice: fix tunnel TSO capabilities
    48efa16873 net/ice: fix link update
    c655f20c8f net/ixgbe: fix memoy leak after device init failure
    3defa10a78 net/iavf: fix memory leak on security context error
    ca47a866b5 net/i40e: remove redundant judgment in flow parsing
    ec5fe01a28 dma/dpaa2: fix logtype register
    fd6f07da94 lib: remove redundant newline from logs
    ec5e780f09 lib: add newline in logs
    e421bcd708 lib: use dedicated logtypes and macros
    f1e3dec4b4 regexdev: fix logtype register
    dc0428a5e4 hash: remove some dead code
    2c512fe65a buildtools/cmdline: fix IP address initializer
    3cedd8b9e4 buildtools/cmdline: fix generated code for IP addresses


* Wed Oct 23 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-11
- Merging upstream branch-3.4 [RH git: c1a17e3dc6]
    Commit list:
    7e0f702fd3 dpdk: Use DPDK 23.11.2 release for OVS 3.4.


* Wed Oct 23 2024 Timothy Redaelli <tredaelli@redhat.com> - 3.4.0-10
- Add OVS_SHA_REF to correctly point to v3.4.0 commit [RH git: 69a101f196]
    This is needed since the current starting commit includes also
    "Prepare for 3.4.1." and this breaks any commits that includes changes
    on NEWS file


* Mon Oct 07 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-9
- Merging upstream branch-3.4 [RH git: fd0f5ba088]
    Commit list:
    a15ce086d4 ofproto-dpif: Improve load balancing in dp_hash select groups. (FDP-826)


* Thu Oct 03 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-8
- Merging upstream branch-3.4 [RH git: af82ab5cba]
    Commit list:
    f6329c4280 Revert "ci: Use sarif-tools v3.0.1 due to issues in earlier versions."
    b7a277b732 ci: Use sarif-tools v3.0.1 due to issues in earlier versions.


* Mon Sep 23 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-7
- Merging upstream branch-3.4 [RH git: d05a073041]
    Commit list:
    d17dbccf03 netdev-dpdk: Disable outer udp checksum offload for txgbe driver.


* Fri Sep 20 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-6
- Merging upstream branch-3.4 [RH git: 0037d59a9b]
    Commit list:
    e05a769314 selinux: Update policy file.


* Fri Sep 20 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-5
- Merging upstream branch-3.4 [RH git: 17b80cd265]
    Commit list:
    7d074979f3 github: Skip FTP SNAT orig tuple tests due to broken Ubuntu kernel.


* Mon Sep 16 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-4
- Merging upstream branch-3.4 [RH git: 743a772569]
    Commit list:
    76ba41b5c2 vconn: Always properly free flow stats reply.
    fa840997f5 mcast-snooping: Properly check group_get_lru return code.
    64cb905077 ovsdb-idl: Fix IDL memory leak.
    9e9433ec5b ofproto/bond: Preserve active bond member over restarts.
    05b7520826 ofproto-dpif-upcall: Avoid stale ukeys leaks.
    a91553ef0e ci: Use previous sarif-tools release due to issue in latest release.


* Thu Aug 29 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-3
- Merging upstream branch-3.4 [RH git: 7e8c8356c9]
    Commit list:
    a67c12d515 userspace: Correctly set ip offload flag in native tunneling.


* Tue Aug 27 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.4.0-2
- Merging upstream branch-3.4 [RH git: 0f5878ad5e]
    Commit list:
    32ff65ac6f docs: Fix argument formatting in ovs-appctl(8) man page.


* Thu Aug 15 2024 Michael Santana <msantana@redhat.com> - 3.4.0-1
- redhat: Use official 3.4.0 tarball [RH git: fc198c51c1]
    Signed-off-by: Michael Santana <msantana@redhat.com>


